@@ -3,13 +3,13 @@
 #' This is a helper function to work with Element_norm() and Element_denorm(). Takes long pivoted data to match element name and add normalizing values from the Element_data dataset.
 #'
 #'
+#' @param chondrite PalmeOneill2014CI, Oneill2014Mantle, McDonough1995CI
 #' @param dat Dataframe or tibble.
-#' @param method Values to normalize: an option from: PalmeOneill2014CI, Oneill2014Mantle, McDonough1995CI.
-#'load
+#'doc
 #' @return a data frame or tibble
 #'
 
-add_NormValues <- function(dat, method = PalmeOneill2014CI) {
+add_NormValues <- function(dat, chondrite = PalmeOneill2014CI) {
 
  Element_name <-  PalmeOneill2014CI <- NULL
 
@@ -18,7 +18,7 @@ add_NormValues <- function(dat, method = PalmeOneill2014CI) {
     stop("dat should be a dataframe, you provided:", class(dat)[1])
   }
 
-Element_Data <-  Element_Data %>% dplyr::select({{method}}, Element_name)
+Element_Data <-  Element_Data %>% dplyr::select({{chondrite}}, Element_name)
 
 dat <- dplyr::left_join(dat, Element_Data, by = 'Element_name')
 
